@@ -42,7 +42,7 @@ extern struct TransUnit TransUnits[];
 // Loads the settings file and stores the settings.
 bool loadSettings()
 {
-    QSettings settings("qucs","qucs");
+    QSettings settings("qucs","qucs_s");
     settings.beginGroup("QucsTranscalc");
     if(settings.contains("x"))QucsSettings.x=settings.value("x").toInt();
     if(settings.contains("y"))QucsSettings.y=settings.value("y").toInt();
@@ -71,7 +71,7 @@ bool loadSettings()
 // Saves the settings in the settings file.
 bool saveApplSettings(QucsTranscalc *qucs)
 {
-    QSettings settings ("qucs","qucs");
+    QSettings settings ("qucs","qucs_s");
     settings.beginGroup("QucsTranscalc");
     settings.setValue("x", qucs->x());
     settings.setValue("y", qucs->y());
@@ -108,7 +108,7 @@ int main(int argc, char *argv[])
   QucsSettings.res_unit = 0;
   QucsSettings.ang_unit = 0;
   QucsSettings.freq_unit = 0;
-  QucsSettings.QucsHomeDir.setPath(QDir::homePath() + "/.qucs");
+  QucsSettings.QucsHomeDir.setPath(QDir::homePath() + "/QucsWorkspace");
 
   // is application relocated?
   char * var = getenv ("QUCSDIR");
