@@ -26,8 +26,9 @@ public:
   ~RLCG();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
+
 protected:
-  QString spice_netlist(bool isXyce);
+  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 };
 
 #endif
