@@ -27,6 +27,8 @@ public:
  ~TLine_4Port();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
+protected:
+  QString spice_netlist(spicecompat::SpiceDialect dialect);
 };
 
 #endif
