@@ -32,7 +32,7 @@ public:
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
 protected:
-  QString spice_netlist(bool isXyce = false);
+  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 };
 
 #endif
