@@ -28,7 +28,7 @@ public:
   ~SpiceFunc();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
-  QString getExpression(bool isXyce);
+  QString getExpression(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 
 protected:
   QString vhdlCode(int) { return QString(); }
